==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ps.js <==
OC.L10N.register(
    "files",
    {
    "All files" : "ټول فایلونه",
    "Recent" : "وروستي",
    "Favorites" : "په نښه شوي",
    "File could not be found" : "فایل نشته",
    "Move or copy" : "انتقال یا کاپي کول",
    "Download" : "ښکته کول",
    "Delete" : "ړنګول",
    "Home" : "کور",
    "Close" : "بندول",
    "Could not create folder \"{dir}\"" : "\"{dir}\" فولډر نشي جوړېدای",
    "This will stop your current uploads." : "دا به اوسني فايلونه پورته کول بند کړي.",
    "Upload cancelled." : "فایل پورته کول بند شول.",
    "Processing files …" : "فایلونه د چمتووالي په حال کې دي ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} فایل نشي پورته کېدای ځکه چې تش دی. 0",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" فولډر نور شتون نلري",
    "Not enough free space" : "تش ځای نشته",
    "An unknown error has occurred" : "ستونزه وه.",
    "Uploading …" : "فايل د پورته کېدو په حال کې دی ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} له {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "دا ډول فایل نشئ پورته کولای",
    "Target folder does not exist any more" : "دغه فولډر نور شتون نلري",
    "Actions" : "کړنې",
    "Rename" : "نوم بدلول",
    "Copy" : "کاپي کول",
    "Choose target folder" : "د ورانتقالېدو فولډر ټاکل",
    "Open" : "پرانيستل",
    "Unshare" : "له شرېکوالي ويستل",
    "Could not load info for file \"{file}\"" : "د \"{file}\" فایل معلومات نشي پرانيستل کېدای",
    "Files" : "فایلونه",
    "Details" : "معلومات",
    "Select" : "ټاکل",
    "Pending" : "د انتظار په حال کې",
    "Unable to determine date" : "نېټه نه معلومېږي",
    "This operation is forbidden" : "دا کړنه نشي کېدای",
    "Could not move \"{file}\", target exists" : "\"{file}\" فایل نشي انتقالېدای ځکه هلته له مخه شتون لري",
    "Could not move \"{file}\"" : "\"{file}\" فایل نشي انتقالېدای",
    "copy" : "کاپي",
    "Could not copy \"{file}\", target exists" : "\"{file}\" فایل نشي کاپي کېدای ځکه هلته له مخه شتون لري",
    "Could not copy \"{file}\"" : "\"{file}\" فایل نشي کاپي کېدای",
    "Copied {origin} inside {destination}" : "له {origin} څخه {destination} کاپي شو",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} او {nbfiles} نور فایلونه {destination} ته کاپي شول",
    "{newName} already exists" : "{newName} له پخوا شتون لري",
    "No search results in other folders for {tag}{filter}{endtag}" : "په نورو فولډرونو کې د {tag}{filter}{endtag} لپاره پايلې نه وې",
    "Name" : "نوم",
    "Size" : "کچه",
    "Modified" : "د بدلون نېټه",
    "_%n folder_::_%n folders_" : ["%n فولډر","%n فولډرونه"],
    "_%n file_::_%n files_" : ["%n فایل","%n فایلونه"],
    "{dirs} and {files}" : "{dirs} او {files}",
    "_including %n hidden_::_including %n hidden_" : [" پټ سربېره","%n پټ سربېره"],
    "You don’t have permission to upload or create files here" : "تاسې په دې ځای کې د فایل يا فولډر جوړولو اجازه نلرئ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n فایل پورته کول","%n فایلونه پورته کول"],
    "New" : "نوی",
    "Select file range" : "د فایلونو اندازه وټاکئ",
    "{used} of {quota} used" : "له {quota} څخه {used} کارول شوې",
    "{used} used" : "{used} کارول شوې",
    "\"{name}\" is an invalid file name." : "\"{name}\" د فایل لپاره سم نوم نه دی",
    "File name cannot be empty." : "فایل نوم تش نشي کېدای",
    "\"/\" is not allowed inside a file name." : "د فایل په نوم کې \"/\" نشئ کارولای",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ډول فایلونو اجازه نشته",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' په څېر","'{filter}' په څېر"],
    "View in folder" : "په فولډر کې کتل",
    "Copied!" : "کاپي شو!",
    "Copy direct link (only works for users who have access to this file/folder)" : "نېغ لېنک کاپي کول",
    "Path" : "درک",
    "_%n byte_::_%n bytes_" : ["%n بایټ","%n بايټونه"],
    "Favorited" : "په نښه شو",
    "Favorite" : "په نښه شوی",
    "You can only favorite a single file or folder at a time" : "په يو وخت یو فایل یا فولډر په نښه کېدای شي",
    "New folder" : "نوی فولډر",
    "Upload file" : "فایل پورته کول",
    "Not favorited" : "په نښه شوی نه دی",
    "Remove from favorites" : "له نښو ويستل",
    "Add to favorites" : "په نښه کول",
    "Added to favorites" : "په نښه شو",
    "Removed from favorites" : "له نښو لېرې شو",
    "You added {file} to your favorites" : "تاسې خپلو په نښه شويو فایلونو ته {file} ورډېر کړ",
    "You removed {file} from your favorites" : "تاسې له خپلو په نښه شويو فایلونو څخه {file} لرې کړ",
    "File changes" : "د فایل بدلونونه",
    "Created by {user}" : "{user} لخوا جوړ شوی",
    "Changed by {user}" : "{user} لخوا تغیر شوی",
    "Deleted by {user}" : "{user} لخوا ړنګ شوی",
    "Restored by {user}" : "{user} لخوا بېرته اصلي شوی",
    "Renamed by {user}" : "{user} لخوا بیا نومول شوی",
    "Moved by {user}" : "{user} لخوا انتقال شوی",
    "\"remote user\"" : "\"د بل ځای کارن\"",
    "You created {file}" : "تاسې {file} جوړ کړی",
    "{user} created {file}" : "{user} کارن {file} فایل جوړ کړ",
    "{file} was created in a public folder" : "{file} په یو عمومي فولډر کې جوړ شوی",
    "You changed {file}" : "تاسې په {file} کې تغیر راوستی",
    "{user} changed {file}" : "{user} کارن {file} فایل کې تغیر رواستی",
    "You deleted {file}" : "تاسې {file} ړنګ کړی",
    "{user} deleted {file}" : "{user} کارن {file} فایل ړنګ کړ",
    "You restored {file}" : "تاسې {file} اصلي حالت ته کړی",
    "{user} restored {file}" : "{user} کارن {file} فایل اصلي حالت ته کړی",
    "You renamed {oldfile} to {newfile}" : "تاسې {oldfile} فایل {newfile} نوم ته اړولی ",
    "{user} renamed {oldfile} to {newfile}" : "{user} {oldfile} فایل {newfile} نوم ته اړولی ",
    "Upload (max. %s)" : "پورته کول (%s نهايي)",
    "File Management" : "فایلونه ترتیبول",
    "Settings" : "سمونې",
    "Show hidden files" : "پټ فایلونه ليدل",
    "Toggle grid view" : "په جدولي شکل ليدل",
    "No files in here" : "دلته فایلونه نشته",
    "No entries found in this folder" : "په دې فولډر کې څه نشته",
    "Select all" : "ټول ټاکل",
    "Upload too large" : "د پورته کېدونکي فایل کچه لوړه ده",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "د دې سرور لپاره د پورته کېدونکي فایل کچه لوړه ده",
    "No favorites yet" : "تر اوسه نښې نشته",
    "Files and folders you mark as favorite will show up here" : "هغه فایلونه او فولډرې چې تاسې په نښه کړئ دلته به ښکاري",
    "Tags" : "نښکې",
    "Deleted files" : "ړنګ شوي فایلونه",
    "Shares" : "شريک شوي",
    "Shared with others" : "نورو سره شريک شوي",
    "Shared with you" : "تاسې سره شريک شوي",
    "Shared by link" : "په لېنک شريک شوي",
    "Deleted shares" : "ړنګ شوي لېنکونه",
    "Text file" : "متن فایل",
    "New text file.txt" : "New text file.txt",
    "Target folder" : "د ورانتقالېدو فولډر",
    "File handling" : "فایلونه سمبالول",
    "Save" : "ساتل",
    "Cancel upload" : "پرېښودل"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ps.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "ذخیره د لنډې مودې لپاره نشته",
    "Storage invalid" : "ذخیره ناسمه ده",
    "Unknown error" : "نامعلومه ستونزه",
    "All files" : "ټول فایلونه",
    "Recent" : "وروستي",
    "Favorites" : "په نښه شوي",
    "File could not be found" : "فایل نشته",
    "Move or copy" : "انتقال یا کاپي کول",
    "Download" : "ښکته کول",
    "Delete" : "ړنګول",
    "Home" : "کور",
    "Close" : "بندول",
    "Could not create folder \"{dir}\"" : "\"{dir}\" فولډر نشي جوړېدای",
    "This will stop your current uploads." : "دا به اوسني فايلونه پورته کول بند کړي.",
    "Upload cancelled." : "فایل پورته کول بند شول.",
    "Processing files …" : "فایلونه د چمتووالي په حال کې دي ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} فایل نشي پورته کېدای ځکه چې تش دی. 0",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "تاسې  {size1} پورته کوئ خو يوازې {size2} پاتې دی او ځای کم دی. ",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" فولډر نور شتون نلري",
    "Not enough free space" : "تش ځای نشته",
    "An unknown error has occurred" : "ستونزه وه.",
    "Uploading …" : "فايل د پورته کېدو په حال کې دی ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} له {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "دا ډول فایل نشئ پورته کولای",
    "Target folder does not exist any more" : "دغه فولډر نور شتون نلري",
    "Actions" : "کړنې",
    "Rename" : "نوم بدلول",
    "Copy" : "کاپي کول",
    "Choose target folder" : "د ورانتقالېدو فولډر ټاکل",
    "Open" : "پرانيستل",
    "Unshare" : "له شرېکوالي ويستل",
    "Could not load info for file \"{file}\"" : "د \"{file}\" فایل معلومات نشي پرانيستل کېدای",
    "Files" : "فایلونه",
    "Details" : "معلومات",
    "Select" : "ټاکل",
    "Pending" : "د انتظار په حال کې",
    "Unable to determine date" : "نېټه نه معلومېږي",
    "This operation is forbidden" : "دا کړنه نشي کېدای",
    "Could not move \"{file}\", target exists" : "\"{file}\" فایل نشي انتقالېدای ځکه هلته له مخه شتون لري",
    "Could not move \"{file}\"" : "\"{file}\" فایل نشي انتقالېدای",
    "copy" : "کاپي",
    "Could not copy \"{file}\", target exists" : "\"{file}\" فایل نشي کاپي کېدای ځکه هلته له مخه شتون لري",
    "Could not copy \"{file}\"" : "\"{file}\" فایل نشي کاپي کېدای",
    "Copied {origin} inside {destination}" : "له {origin} څخه {destination} کاپي شو",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} او {nbfiles} نور فایلونه {destination} ته کاپي شول",
    "{newName} already exists" : "{newName} له پخوا شتون لري",
    "Could not rename \"{fileName}\"" : " \"{fileName}\" فایل نوم نشئ بدلولی",
    "Could not create file \"{file}\"" : "\"{file}\" فایل نشي جوړېدای",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" فایل موجود دی. بيا يې نشئ جوړولی.",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" فولډر موجود دی. بيا يې نشئ جوړولی.",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" فايل پاکولو کې ستونزه ده",
    "No search results in other folders for {tag}{filter}{endtag}" : "په نورو فولډرونو کې د {tag}{filter}{endtag} لپاره پايلې نه وې",
    "Name" : "نوم",
    "Size" : "کچه",
    "Modified" : "د بدلون نېټه",
    "_%n folder_::_%n folders_" : ["%n فولډر","%n فولډرونه"],
    "_%n file_::_%n files_" : ["%n فایل","%n فایلونه"],
    "{dirs} and {files}" : "{dirs} او {files}",
    "_including %n hidden_::_including %n hidden_" : [" پټ سربېره","%n پټ سربېره"],
    "You don’t have permission to upload or create files here" : "تاسې په دې ځای کې د فایل يا فولډر جوړولو اجازه نلرئ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n فایل پورته کول","%n فایلونه پورته کول"],
    "New" : "نوی",
    "Select file range" : "د فایلونو اندازه وټاکئ",
    "{used} of {quota} used" : "له {quota} څخه {used} کارول شوې",
    "{used} used" : "{used} کارول شوې",
    "\"{name}\" is an invalid file name." : "\"{name}\" د فایل لپاره سم نوم نه دی",
    "File name cannot be empty." : "فایل نوم تش نشي کېدای",
    "\"/\" is not allowed inside a file name." : "د فایل په نوم کې \"/\" نشئ کارولای",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ډول فایلونو اجازه نشته",
    "Your storage is almost full ({usedSpacePercent}%)" : "({usedSpacePercent}%) ستاسې ذخیره تقریبا ډکه ده ",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' په څېر","'{filter}' په څېر"],
    "View in folder" : "په فولډر کې کتل",
    "Copied!" : "کاپي شو!",
    "Copy direct link (only works for users who have access to this file/folder)" : "نېغ لېنک کاپي کول",
    "Path" : "درک",
    "_%n byte_::_%n bytes_" : ["%n بایټ","%n بايټونه"],
    "Favorited" : "په نښه شو",
    "Favorite" : "په نښه شوی",
    "You can only favorite a single file or folder at a time" : "په يو وخت یو فایل یا فولډر په نښه کېدای شي",
    "New folder" : "نوی فولډر",
    "Upload file" : "فایل پورته کول",
    "Not favorited" : "په نښه شوی نه دی",
    "Remove from favorites" : "له نښو ويستل",
    "Add to favorites" : "په نښه کول",
    "Added to favorites" : "په نښه شو",
    "Removed from favorites" : "له نښو لېرې شو",
    "You added {file} to your favorites" : "تاسې خپلو په نښه شويو فایلونو ته {file} ورډېر کړ",
    "You removed {file} from your favorites" : "تاسې له خپلو په نښه شويو فایلونو څخه {file} لرې کړ",
    "File changes" : "د فایل بدلونونه",
    "Created by {user}" : "{user} لخوا جوړ شوی",
    "Changed by {user}" : "{user} لخوا تغیر شوی",
    "Deleted by {user}" : "{user} لخوا ړنګ شوی",
    "Restored by {user}" : "{user} لخوا بېرته اصلي شوی",
    "Renamed by {user}" : "{user} لخوا بیا نومول شوی",
    "Moved by {user}" : "{user} لخوا انتقال شوی",
    "\"remote user\"" : "\"د بل ځای کارن\"",
    "You created {file}" : "تاسې {file} جوړ کړی",
    "{user} created {file}" : "{user} کارن {file} فایل جوړ کړ",
    "{file} was created in a public folder" : "{file} په یو عمومي فولډر کې جوړ شوی",
    "You changed {file}" : "تاسې په {file} کې تغیر راوستی",
    "You changed an encrypted file in {file}" : " تاسې په {file} کې يو خوندي فایل بدل کړ",
    "{user} changed {file}" : "{user} کارن {file} فایل کې تغیر رواستی",
    "{user} changed an encrypted file in {file}" : "{user} يو خوندي فايل په {file} کې بدل کړ",
    "You deleted {file}" : "تاسې {file} ړنګ کړی",
    "You deleted an encrypted file in {file}" : "تاسې په {file} کې يو خوندي فايل ړنګ کړ",
    "{user} deleted {file}" : "{user} کارن {file} فایل ړنګ کړ",
    "{user} deleted an encrypted file in {file}" : "{user} په {file} کې يو خوندي فايل ړنګ کړ",
    "You restored {file}" : "تاسې {file} اصلي حالت ته کړی",
    "{user} restored {file}" : "{user} کارن {file} فایل اصلي حالت ته کړی",
    "You renamed {oldfile} to {newfile}" : "تاسې {oldfile} فایل {newfile} نوم ته اړولی ",
    "{user} renamed {oldfile} to {newfile}" : "{user} {oldfile} فایل {newfile} نوم ته اړولی ",
    "Unlimited" : "نامحدود",
    "Upload (max. %s)" : "پورته کول (%s نهايي)",
    "File Management" : "فایلونه ترتیبول",
    "%s used" : "%sکارول شوې",
    "%1$s of %2$s used" : "د %2$sبرخې %1$sکارول شوې",
    "Settings" : "سمونې",
    "Show hidden files" : "پټ فایلونه ليدل",
    "Toggle grid view" : "په جدولي شکل ليدل",
    "No files in here" : "دلته فایلونه نشته",
    "No entries found in this folder" : "په دې فولډر کې څه نشته",
    "Select all" : "ټول ټاکل",
    "Upload too large" : "د پورته کېدونکي فایل کچه لوړه ده",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "د دې سرور لپاره د پورته کېدونکي فایل کچه لوړه ده",
    "No favorites yet" : "تر اوسه نښې نشته",
    "Files and folders you mark as favorite will show up here" : "هغه فایلونه او فولډرې چې تاسې په نښه کړئ دلته به ښکاري",
    "Tags" : "نښکې",
    "Deleted files" : "ړنګ شوي فایلونه",
    "Shares" : "شريک شوي",
    "Shared with others" : "نورو سره شريک شوي",
    "Shared with you" : "تاسې سره شريک شوي",
    "Shared by link" : "په لېنک شريک شوي",
    "Deleted shares" : "ړنګ شوي لېنکونه",
    "Text file" : "متن فایل",
    "New text file.txt" : "New text file.txt",
    "Target folder" : "د ورانتقالېدو فولډر",
    "File handling" : "فایلونه سمبالول",
    "Maximum upload size" : "د پورته کولو تر ټولو زیاته اندازه",
    "Save" : "ساتل",
    "%s of %s used" : "د %sبرخې %sکارول شوې",
    "Cancel upload" : "پرېښودل",
    "%1$s%% of %2$s used" : "د %2$sبرخې %1$s%%کارول شوې"
},
"nplurals=2; plural=(n != 1);");
